[project]
name = "{{ name }}"
version = "{{ version }}"
description = "{{ description }}"
readme = "README.md"
authors = [{ name = "{{ author }}", email = "" }]
requires-python = ">={{ python_version }}"

# Dependencies
dependencies = [
    "fletxr=={{ fletx_version }}",
    "flet==0.28.3",
]
